scanResultCallBack method
barcode, qrcode, any, pivot scanning results are obtained here
Implementation
void scanResultCallBack(ScanResultSuccess result) {
if (callback != null) {
callback!.onScanResultSuccess(result);
}
}
barcode, qrcode, any, pivot scanning results are obtained here
void scanResultCallBack(ScanResultSuccess result) {
if (callback != null) {
callback!.onScanResultSuccess(result);
}
}